@@ -30,6 +30,9 @@ def create_radix_config(
     template = template_environment.get_template("radixconfig.yaml.jinja2")
 
     (build_directory / "radixconfig.yaml").write_text(template.render(settings))
+    (build_directory / "auth-state.Dockerfile").write_text(
+        "FROM redis:alpine\nUSER 999"
+    )
 
 
 def website_online(url: str) -> bool:
@@ -215,10 +218,10 @@ def radix_initial_deployment(github_slug: str, build_directory: pathlib.Path) ->
         progress_bar.update()
 
     for key, value in {
-        "main-storage1-blobfusecreds-accountkey": azure_configuration_values[
+        "main-appstorage-csiazurecreds-accountkey": azure_configuration_values[
             "storage_account_key_secret"
         ],
-        "main-storage1-blobfusecreds-accountname": azure_configuration_values[
+        "main-appstorage-csiazurecreds-accountname": azure_configuration_values[
             "storage_account_name"
         ],
     }.items():
